@@ -1947,6 +1947,10 @@ start_type (GMarkupParseContext *context,
           const char *cp = ctype + strlen(ctype) - 1;
           while (cp > ctype && *cp-- == '*')
             pointer_depth++;
+
+	  if (g_str_has_prefix (ctype, "gpointer")
+	      || g_str_has_prefix (ctype, "gconstpointer"))
+	    pointer_depth++;
         }
 
       if (ctx->current_typed->type == G_IR_NODE_PARAM &&
@@ -3498,6 +3502,11 @@ _g_ir_parser_parse_string (GIrParser           *parser,
 
   if (ctx.modules)
     return ctx.modules->data;
+
+  g_set_error (error,
+               G_MARKUP_ERROR,
+               G_MARKUP_ERROR_INVALID_CONTENT,
+               "Expected namespace element in the gir file");
   return NULL;
 }
 
